@@ -11,7 +11,7 @@ from hdfs3 import HDFileSystem
 from Accuinsight.modeler.core.LcConst.LcConst import ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.utils.runs_utils import ProgressPercentage
 from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
-from Accuinsight.modeler.utils.os_getenv import get_os_env
+from Accuinsight.modeler.utils.os_getenv import get_os_env, get_current_notebook
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.entities.alarm import Alarm
 
@@ -35,6 +35,7 @@ class Common(object):
                                                     env_value[LcConst.BACK_END_API_PORT],
                                                     env_value[LcConst.BACK_END_API_URI])
         self.workspace_alarm = Alarm()
+        self.notebook_info = get_current_notebook()
 
     def set_storage(self,
                     access_key=None,  # aws-s3
@@ -291,3 +292,17 @@ class Common(object):
                 raise ValueError('입력값으로 list 또는 pandas.core.indexes.base.Index를 사용하시기 바랍니다.')
 
         return feature_names
+
+    @staticmethod
+    def get_current_run_id():
+        try:
+            with open('/home/work/runs/run_info.json') as json_file:
+                return json.load(json_file)['run_name']
+        except FileNotFoundError or KeyError:
+            return ''
+
+    def set_current_notebook(self):
+        self.notebook_info = get_current_notebook()
+
+    def get_current_notebook(self):
+        return self.notebook_info
